summaryrefslogtreecommitdiffstats
path: root/lib/interfaces/kdevlanguagesupport.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/interfaces/kdevlanguagesupport.h')
-rw-r--r--lib/interfaces/kdevlanguagesupport.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/lib/interfaces/kdevlanguagesupport.h b/lib/interfaces/kdevlanguagesupport.h
index 78694193..765fde79 100644
--- a/lib/interfaces/kdevlanguagesupport.h
+++ b/lib/interfaces/kdevlanguagesupport.h
@@ -61,6 +61,7 @@ formatted name).
class KDevLanguageSupport: public KDevPlugin
{
Q_OBJECT
+ TQ_OBJECT
public:
@@ -90,10 +91,10 @@ public:
plugin information in various places like "about application" dialog, plugin selector
dialog, etc. Plugin does not take ownership on info object, also its lifetime should
be equal to the lifetime of the plugin.
- @param parent The parent object for the plugin. Parent object must implement @ref KDevApi
+ @param tqparent The tqparent object for the plugin. Parent object must implement @ref KDevApi
interface. Otherwise the plugin will not be constructed.
@param name The internal name which identifies the plugin.*/
- KDevLanguageSupport(const KDevPluginInfo *info, TQObject *parent, const char *name);
+ KDevLanguageSupport(const KDevPluginInfo *info, TQObject *tqparent, const char *name);
/**Destructor.*/
~KDevLanguageSupport();
@@ -164,13 +165,13 @@ public:
*/
virtual void createAccessMethods(ClassDom theClass, VariableDom theVariable);
/**Opens an "Subclass Widget" dialog for given Qt .ui file (formName)
and propmts to implement it's slots.
@param formName The name of a form to subclass.
@return A list of newly created files.*/
virtual TQStringList subclassWidget(const TQString& formName);
/**Opens an "Update Widget" dialog for given Qt .ui file (formName)
and prompts to add missing slot implementations
in the subclass located in fileName.
@param formName The name of a form which is being subclassed.
@@ -185,12 +186,12 @@ public:
KDevDesignerIntegration *des = 0;
switch (type)
{
- case KInterfaceDesigner::QtDesigner:
+ case KInterfaceDesigner::TQtDesigner:
des = getDesignerFromCache(type);
if (des == 0)
{
MyLanguageImplementationWidget *impl = new MyLanguageImplementationWidget(this);
- des = new QtDesignerMyLanguageIntegration(this, impl);
+ des = new TQtDesignerMyLanguageIntegration(this, impl);
des->loadSettings(*project()->projectDom(), "kdevmylangsupport/designerintegration");
saveDesignerToCache(type, des);
}
@@ -198,7 +199,7 @@ public:
}
return des;
@endcode
- @ref ImplementationWidget and @ref QtDesignerIntegration classes are available
+ @ref ImplementationWidget and @ref TQtDesignerIntegration classes are available
from designerintegration support library.
@param type The type of the designer to integrate.
@return The pointer to designer integration of given type or 0.*/
@@ -164,13 +165,13 @@ public:
*/
virtual void createAccessMethods(ClassDom theClass, VariableDom theVariable);
- /**Opens an "Subclass Widget" dialog for given Qt .ui file (formName)
+ /**Opens an "Subclass Widget" dialog for given TQt .ui file (formName)
and propmts to implement it's slots.
@@ -164,13 +165,13 @@ public:
virtual TQStringList subclassWidget(const TQString& formName);
- /**Opens an "Update Widget" dialog for given Qt .ui file (formName)
+ /**Opens an "Update Widget" dialog for given TQt .ui file (formName)
and prompts to add missing slot implementations
in the subclass located in fileName.